.. _OASIS_pvalue:

`OASIS_pvalue`
==============

.. automodule:: oasis_stat
   :members: OASIS_pvalue
   :undoc-members:
   :show-inheritance:

Description
-----------
Primary function for computing OASIS pvalue. Generates random splits, optimizes embeddings over training data and computes on test, returns results for best split corrected for multiple hypothesis testing.